import { promises as fs } from 'fs';
import axios from "axios";
import readline from "readline"
import path from 'path';
import { v4 as uuid } from 'uuid'; // 或使用 crypto 模块
const downloadDir = path.join(__dirname, '../../downloads');

export function askQuestion(query: string) {
    return new Promise((resolve, reject) => {
        const rl = readline.createInterface({
            input: process.stdin,
            output: process.stdout
        });

        rl.question(query, (answer: string) => {
            rl.close();
            resolve(answer);
        });
    });
}
export async function downloadImage(url: string) {
    try {
        // 获取图片响应
        const response = await axios.get(url, {
            responseType: 'arraybuffer',
            headers: {
                'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36'
            }
        });

        // 获取文件扩展名
        
        const ext = response.headers['content-type']?.split('/')[1] || 'jpg';
        const id = uuid()
        // 生成最终路径
        const filename = `${id}.${ext}`;
        const filePath = path.join(downloadDir, filename);

        // 写入文件
        await fs.writeFile(filePath, response.data);
        return filename;
    } catch (error) {
        console.error('下载失败:', error);
        throw error;
    }
}

